@@ -1,5 +1,5 @@
 package App::Oozie::Deploy;
-$App::Oozie::Deploy::VERSION = '0.008';
+$App::Oozie::Deploy::VERSION = '0.009';
 use 5.010;
 use strict;
 use warnings;
@@ -28,6 +28,7 @@ use App::Oozie::Constants qw( OOZIE_STATES_RUNNING );
 
 use Carp ();
 use Config::Properties;
+use Config::General ();
 use DateTime::Format::Strptime;
 use DateTime;
 use Email::Valid;
@@ -110,6 +111,15 @@ option dump_xml_to_json => (
     doc     => 'Specify a directory to convert and dump XML files in the workflow as JSON. This implies a dryrun.',
 );
 
+option hdfs_properties_file => (
+    is      => 'rw',
+    isa     => Str,
+    format  => 's',
+    # i.e.: /share/oozie.properties
+    doc     => 'The location of the optional properties file on HDFS',
+);
+
+
 #------------------------------------------------------------------------------#
 
 has required_tt_files => (
@@ -188,6 +198,14 @@ has configuration_files => (
     is      => 'rw',
     # TODO: type needs fixing for coercion
     # isa     => ArrayRef[IsFile],
+    lazy    => 1,
+    default => sub {
+        my $self  = shift;
+        my $ttlib = $self->ttlib_base_dir;
+        [
+            File::Spec->catfile( $ttlib, 'common.properties' ),
+        ],
+    },
 );
 
 has email_validator => (
@@ -384,6 +402,24 @@ sub destination_path {
             ;
 }
 
+sub __collect_internal_conf_hdfs {
+    my $self   = shift;
+    my $logger = $self->logger;
+    my $file   = $self->hdfs_properties_file;
+
+    return {} if ! $file; # not specified at all
+
+    $logger->debug( sprintf "If exists, fetching from HDFS: %s", $file );
+
+    return {} if ! $self->_hdfs_exists_no_exception( $file );
+
+    return {
+        Config::General::ParseConfig(
+            -String => $self->hdfs->read( $file ),
+        )
+    };
+}
+
 sub __collect_internal_conf {
     my $self  = shift;
     my $keep  = $self->keep_deploy_path;
@@ -411,6 +447,11 @@ sub __collect_internal_conf {
         }
     }
 
+    $config = {
+        %{ $config },
+        %{ $self->__collect_internal_conf_hdfs },
+    };
+
     my $base_dest = File::Temp::tempdir(
                         CLEANUP => ! $keep,
                         DIR     => resolve_tmp_dir(),
@@ -1190,7 +1231,7 @@ App::Oozie::Deploy
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
